/*! rollup-plugin-relink v0.1.9 by Sebastian Werner */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('fs'), require('path'), require('crypto'), require('denodeify'), require('fs-extra'), require('loader-utils'), require('rollup-pluginutils'), require('postcss'), require('postcss-smart-import'), require('sugarss'), require('postcss-scss')) :
  typeof define === 'function' && define.amd ? define('rollup-plugin-relink', ['fs', 'path', 'crypto', 'denodeify', 'fs-extra', 'loader-utils', 'rollup-pluginutils', 'postcss', 'postcss-smart-import', 'sugarss', 'postcss-scss'], factory) :
  (global.rollupPluginRelink = factory(global.fs,global.path,global.crypto,global.denodeify,global.fse,global.loaderUtils,global.rollupPluginutils,global.postcss,global.postcssSmartImport,global.postcssParserSugarss,global.postcssParserScss));
}(this, (function (fs,path,crypto,denodeify,fse,loaderUtils,rollupPluginutils,postcss,postcssSmartImport,postcssParserSugarss,postcssParserScss) { 'use strict';

fs = 'default' in fs ? fs['default'] : fs;
path = 'default' in path ? path['default'] : path;
crypto = 'default' in crypto ? crypto['default'] : crypto;
denodeify = 'default' in denodeify ? denodeify['default'] : denodeify;
fse = 'default' in fse ? fse['default'] : fse;
postcss = 'default' in postcss ? postcss['default'] : postcss;
postcssSmartImport = 'default' in postcssSmartImport ? postcssSmartImport['default'] : postcssSmartImport;
postcssParserSugarss = 'default' in postcssParserSugarss ? postcssParserSugarss['default'] : postcssParserSugarss;
postcssParserScss = 'default' in postcssParserScss ? postcssParserScss['default'] : postcssParserScss;

var copyAsync = denodeify(fse.copy);
var writeAsync = denodeify(fse.outputFile);

var styleExtensions = {
  ".css": null,
  ".sss": postcssParserSugarss,
  ".scss": postcssParserScss
};

var postcssPlugins = [postcssSmartImport()];

function processStyle(code, id, dest) {
  var parser = styleExtensions[path.extname(id)];
  return postcss(postcssPlugins).process(code, {
    from: id,
    to: dest,
    parser: parser,
    extensions: [".css", ".sss", ".scss"]
  }).then(function (result) {
    return writeAsync(dest, result);
  }).catch(function (err) {
    console.error(err);
  });
}

var hashType = "sha256";
var digestType = "base62";
var digestLength = 8;

var externalIds = {};

var defaultExclude = ["**/*.json", "**/*.js", "**/*.jsx", "**/*.ts", "**/*.tsx", "**/*.es", "**/*.es5", "**/*.es6", "**/*.es7", "**/*.vue"];

function relink() {
  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  var limit = options.limit;
  var include = options.include;
  var _options$exclude = options.exclude;
  var exclude = _options$exclude === undefined ? defaultExclude : _options$exclude;
  var outputFolder = options.outputFolder;
  var verbose = options.verbose;

  var filter = rollupPluginutils.createFilter(include, exclude);

  return {
    name: "rollup-plugin-relink",

    isExternal: function isExternal(id) {
      var baseName = "./" + path.basename(id);
      return baseName in externalIds;
    },

    resolveId: function resolveId(importee) {
      if (importee in externalIds) {
        // This does not yet seem to work!
        // See also: https://github.com/rollup/rollup/issues/861
        // "returning any other falsy value signals that importee should be treated as an external module
        // and not included in the bundle." -- https://github.com/rollup/rollup/wiki/Plugins#creating-plugins
        return false;
      }

      return null;
    },

    load: function load(id) {
      if (!filter(id)) return null;

      var input = fs.createReadStream(id);
      var hash = crypto.createHash("sha256");

      return new Promise(function (resolve, reject) {
        input.on("readable", function () {
          var fileSource = id;
          var fileContent = fs.readFileSync(fileSource);
          var fileExt = path.extname(id);
          var fileHash = loaderUtils.getHashDigest(fileContent, hashType, digestType, digestLength);

          var destExt = fileExt in styleExtensions ? ".css" : fileExt;
          var destId = path.basename(id, fileExt) + "-" + fileHash + destExt;

          var fileDest = path.resolve(outputFolder, destId);

          externalIds["./" + destId] = true;

          if (fileExt in styleExtensions) {
            if (verbose) console.log("Processing " + fileSource + " => " + fileDest + "...");

            return processStyle(fileContent, fileSource, fileDest).then(function () {
              resolve({
                code: "import _" + fileHash + " from \"./" + destId + "\"; export default _" + fileHash + ";",
                map: { mappings: "" }
              });
            });
          } else {
            if (verbose) console.log("Copying " + fileSource + " => " + fileDest + "...");

            return copyAsync(fileSource, fileDest).then(function () {
              resolve({
                code: "import _" + fileHash + " from \"./" + destId + "\"; export default _" + fileHash + ";",
                map: { mappings: "" }
              });
            });
          }
        });
      });
    }
  };
}

return relink;

})));
//# sourceMappingURL=index.umd.js.map
